# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .ml_model_role import MlModelRole

__all__ = ["RoleListResponse"]

RoleListResponse: TypeAlias = List[MlModelRole]
