# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .data_set_info import DataSetInfo

__all__ = ["DatasetListResponse"]

DatasetListResponse: TypeAlias = List[DataSetInfo]
