# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["QuarkTag"]

QuarkTag: TypeAlias = Literal[
    "AI",
    "Base",
    "Completion",
    "Destination",
    "Embeddings",
    "Files",
    "Etl",
    "Llm",
    "MultiModal",
    "Quark",
    "Source",
    "Structured",
    "Text",
]
