# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .source import Source

__all__ = ["SourceListResponse"]

SourceListResponse: TypeAlias = List[Source]
