# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .extractor import Extractor

__all__ = ["ExtractorListResponse"]

ExtractorListResponse: TypeAlias = List[Extractor]
