# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .classifier import Classifier

__all__ = ["ClassifierListResponse"]

ClassifierListResponse: TypeAlias = List[Classifier]
